#
# spec file for package python-yamale
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-yamale
Version:        6.0.0
Release:        1.4
Summary:        A schema and validator for YAML
License:        MIT
URL:            https://github.com/23andMe/Yamale
Source:         https://github.com/23andMe/Yamale/archive/refs/tags/%{version}.tar.gz#/yamale-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module ruamel.yaml}
# /SECTION
%python_subpackages

%description
A schema and validator for YAML.

%prep
%autosetup -p1 -n Yamale-%{version}

find . -type f -name "*.py" -exec sed -i '/#!\/usr\/bin\/env/d' {} +

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/yamale
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest yamale

%post
%python_install_alternative yamale

%postun
%python_uninstall_alternative yamale

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/yamale
%{python_sitelib}/yamale
%{python_sitelib}/yamale-%{version}*-info/

%changelog
* Fri Jan  3 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 6.0.0:
  * New Features
  - Adds -e PATTERN / --exclude PATTERN argument to the CLI
  - CLI supports -n auto to spawn child processes equal to number
    of system CPUs
  * Breaking Changes
  - Enforces all paths supplied to the command line interface
    must exist
* Wed Jan  1 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 5.3.0:
  * Create .pre-commit-hooks.yaml by @rsrdesarrollo in #258
  * feat: support multiple paths in yamale by @thiagowfx in #251
  * pre-commit: set pass_filenames to true by @thiagowfx in #260
  * Support 3.13, add [ruamel] optional package dep by @cblakkan in
    [#257]
* Thu May  2 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 5.2.1:
  * (fix)semver: SyntaxWarning: invalid escape sequence by @kiblik
    in #248
* Thu Apr 25 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 5.2.0:
  * Add CodeQL workflow for GitHub code scanning by @lgtm-com in #205
  * Add ruff gh action by @cblakkan in #244
  * Hard fail on undefined includes by @cblakkan in #247
  * Add semantic versioning (semver.org) validator by @thiagowfx in #246
* Wed Mar 20 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 5.1.0:
  * fix(cli): check schema to be a valid path first by
    @AndreyNautilus in #241
  * Ruff format codebase by @cblakkan in #243
* Mon Mar 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 5.0.0:
  * fix 3.12 deprecations by @sigma67 in #237
  * Prep for 5.0.0; Run tests on 3.8, 3.12 by @cblakkan in #240
* Fri May  5 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Tue Mar 28 2023 Matej Cepl <mcepl@suse.com>
- Clean up SPEC file
* Mon Mar 27 2023 Johannes Kastl <kastl@b1-systems.de>
- new package yamale, used by Helm's chart-testing package
